@@ -9,13 +9,6 @@ Glyph bitmap monochrome rendring
 '''
 from freetype import *
 
-def bits(x):
-    data = []
-    for i in range(8):
-        data.insert(0, int((x & 1) == 1))
-        x = x >> 1
-    return data
-
 if __name__ == '__main__':
     import numpy
     import matplotlib.pyplot as plt
